receiver

package
v0.0.0-...-eab87ad Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 25, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Chain

type Chain struct {
	// contains filtered or unexported fields
}

func NewChain

func NewChain(receivers ...Receiver) *Chain

func (*Chain) Receive

func (r *Chain) Receive(ctx context.Context, pd pprofile.Profiles) error

func (*Chain) Start

func (r *Chain) Start(ctx context.Context) error

func (*Chain) Stop

func (r *Chain) Stop(ctx context.Context) error

type Receiver

type Receiver interface {
	Start(ctx context.Context) error
	Receive(ctx context.Context, pd pprofile.Profiles) error
	Stop(ctx context.Context) error
}

Directories

Path Synopsis
Package filesystem implements a receiver that persists received profiles to a directory tree.
Package filesystem implements a receiver that persists received profiles to a directory tree.

Jump to